@@ -1,13 +1,12 @@
-import string
-
-import regex as re
-import numpy as np
-import six
-import sys
 import json
+import string
+import sys
 import warnings
-from collections import OrderedDict
-from collections import defaultdict
+from collections import OrderedDict, defaultdict
+
+import numpy as np
+import regex as re
+import six
 from nltk.corpus import stopwords
 from nltk.stem import PorterStemmer, WordNetLemmatizer
 from nltk.tokenize import word_tokenize
@@ -19,8 +18,9 @@ else:
     maketrans = str.maketrans
 
 
-def pad_sequences(sequences, maxlen=None, dtype='int32',
-                  padding='pre', truncating='pre', value=0.):
+def pad_sequences(
+    sequences, maxlen=None, dtype="int32", padding="pre", truncating="pre", value=0.0
+):
     """Pads sequences to the same length.
 
     This function transforms a list of
@@ -59,8 +59,8 @@ def pad_sequences(sequences, maxlen=None, dtype='int32',
         ValueError: In case of invalid values for `truncating` or `padding`,
             or in case of invalid shape for a `sequences` entry.
     """
-    if not hasattr(sequences, '__len__'):
-        raise ValueError('`sequences` must be iterable.')
+    if not hasattr(sequences, "__len__"):
+        raise ValueError("`sequences` must be iterable.")
     num_samples = len(sequences)
 
     lengths = []
@@ -77,49 +77,55 @@ def pad_sequences(sequences, maxlen=None, dtype='int32',
                 sample_shape = np.asarray(x).shape[1:]
                 flag = False
         except TypeError:
-            raise ValueError('`sequences` must be a list of iterables. '
-                             'Found non-iterable: ' + str(x))
+            raise ValueError(
+                "`sequences` must be a list of iterables. "
+                "Found non-iterable: " + str(x)
+            )
 
     if maxlen is None:
         maxlen = np.max(lengths)
 
     is_dtype_str = np.issubdtype(dtype, np.str_) or np.issubdtype(dtype, np.unicode_)
     if isinstance(value, six.string_types) and dtype != object and not is_dtype_str:
-        raise ValueError("`dtype` {} is not compatible with `value`'s type: {}\n"
-                         "You should set `dtype=object` for variable length strings."
-                         .format(dtype, type(value)))
+        raise ValueError(
+            "`dtype` {} is not compatible with `value`'s type: {}\n"
+            "You should set `dtype=object` for variable length strings.".format(
+                dtype, type(value)
+            )
+        )
 
     x = np.full((num_samples, maxlen) + sample_shape, value, dtype=dtype)
     for idx, s in enumerate(sequences):
         if not len(s):
             continue  # empty list/array was found
-        if truncating == 'pre':
+        if truncating == "pre":
             trunc = s[-maxlen:]
-        elif truncating == 'post':
+        elif truncating == "post":
             trunc = s[:maxlen]
         else:
-            raise ValueError('Truncating type "%s" '
-                             'not understood' % truncating)
+            raise ValueError('Truncating type "%s" ' "not understood" % truncating)
 
         # check `trunc` has expected shape
         trunc = np.asarray(trunc, dtype=dtype)
         if trunc.shape[1:] != sample_shape:
-            raise ValueError('Shape of sample %s of sequence at position %s '
-                             'is different from expected shape %s' %
-                             (trunc.shape[1:], idx, sample_shape))
+            raise ValueError(
+                "Shape of sample %s of sequence at position %s "
+                "is different from expected shape %s"
+                % (trunc.shape[1:], idx, sample_shape)
+            )
 
-        if padding == 'post':
-            x[idx, :len(trunc)] = trunc
-        elif padding == 'pre':
-            x[idx, -len(trunc):] = trunc
+        if padding == "post":
+            x[idx, : len(trunc)] = trunc
+        elif padding == "pre":
+            x[idx, -len(trunc) :] = trunc
         else:
             raise ValueError('Padding type "%s" not understood' % padding)
     return x
 
 
-def text_to_word_sequence(text,
-                          filters='!"#$%&()*+,-./:;<=>?@[\\]^_`{|}~\t\n',
-                          lower=True, split=" "):
+def text_to_word_sequence(
+    text, filters='!"#$%&()*+,-./:;<=>?@[\\]^_`{|}~\t\n', lower=True, split=" "
+):
     """Converts a text to a sequence of words (or tokens).
 
     # Arguments
@@ -138,9 +144,7 @@ def text_to_word_sequence(text,
 
     if sys.version_info < (3,):
         if isinstance(text, unicode):  # noqa: F821
-            translate_map = {
-                ord(c): unicode(split) for c in filters  # noqa: F821
-            }
+            translate_map = {ord(c): unicode(split) for c in filters}  # noqa: F821
             text = text.translate(translate_map)
         elif len(split) == 1:
             translate_map = maketrans(filters, split * len(filters))
@@ -186,21 +190,26 @@ class Tokenizer(object):
     `0` is a reserved index that won't be assigned to any word.
     """
 
-    def __init__(self, num_words=None,
-                 filters='!"#$%&()*+,-./:;<=>?@[\\]^_`{|}~\t\n',
-                 lower=True,
-                 split=' ',
-                 char_level=False,
-                 oov_token=None,
-                 document_count=0,
-                 **kwargs):
+    def __init__(
+        self,
+        num_words=None,
+        filters='!"#$%&()*+,-./:;<=>?@[\\]^_`{|}~\t\n',
+        lower=True,
+        split=" ",
+        char_level=False,
+        oov_token=None,
+        document_count=0,
+        **kwargs
+    ):
         # Legacy support
-        if 'nb_words' in kwargs:
-            warnings.warn('The `nb_words` argument in `Tokenizer` '
-                          'has been renamed `num_words`.')
-            num_words = kwargs.pop('nb_words')
+        if "nb_words" in kwargs:
+            warnings.warn(
+                "The `nb_words` argument in `Tokenizer` "
+                "has been renamed `num_words`."
+            )
+            num_words = kwargs.pop("nb_words")
         if kwargs:
-            raise TypeError('Unrecognized keyword arguments: ' + str(kwargs))
+            raise TypeError("Unrecognized keyword arguments: " + str(kwargs))
 
         self.word_counts = OrderedDict()
         self.word_docs = defaultdict(int)
@@ -238,10 +247,7 @@ class Tokenizer(object):
                         text = text.lower()
                 seq = text
             else:
-                seq = text_to_word_sequence(text,
-                                            self.filters,
-                                            self.lower,
-                                            self.split)
+                seq = text_to_word_sequence(text, self.filters, self.lower, self.split)
             for w in seq:
                 if w in self.word_counts:
                     self.word_counts[w] += 1
@@ -261,8 +267,7 @@ class Tokenizer(object):
         sorted_voc.extend(wc[0] for wc in wcounts)
 
         # note that index 0 is reserved, never assigned to an existing word
-        self.word_index = dict(
-            zip(sorted_voc, list(range(1, len(sorted_voc) + 1))))
+        self.word_index = dict(zip(sorted_voc, list(range(1, len(sorted_voc) + 1))))
 
         self.index_word = {c: w for w, c in self.word_index.items()}
 
@@ -325,10 +330,7 @@ class Tokenizer(object):
                         text = text.lower()
                 seq = text
             else:
-                seq = text_to_word_sequence(text,
-                                            self.filters,
-                                            self.lower,
-                                            self.split)
+                seq = text_to_word_sequence(text, self.filters, self.lower, self.split)
             vect = []
             for w in seq:
                 i = self.word_index.get(w)
@@ -385,10 +387,10 @@ class Tokenizer(object):
                         vect.append(word)
                 elif self.oov_token is not None:
                     vect.append(self.index_word[oov_token_index])
-            vect = ' '.join(vect)
+            vect = " ".join(vect)
             yield vect
 
-    def texts_to_matrix(self, texts, mode='binary'):
+    def texts_to_matrix(self, texts, mode="binary"):
         """Convert a list of texts to a Numpy matrix.
 
         # Arguments
@@ -401,7 +403,7 @@ class Tokenizer(object):
         sequences = self.texts_to_sequences(texts)
         return self.sequences_to_matrix(sequences, mode=mode)
 
-    def sequences_to_matrix(self, sequences, mode='binary'):
+    def sequences_to_matrix(self, sequences, mode="binary"):
         """Converts a list of sequences into a Numpy matrix.
 
         # Arguments
@@ -420,14 +422,17 @@ class Tokenizer(object):
             if self.word_index:
                 num_words = len(self.word_index) + 1
             else:
-                raise ValueError('Specify a dimension (`num_words` argument), '
-                                 'or fit on some text data first.')
+                raise ValueError(
+                    "Specify a dimension (`num_words` argument), "
+                    "or fit on some text data first."
+                )
         else:
             num_words = self.num_words
 
-        if mode == 'tfidf' and not self.document_count:
-            raise ValueError('Fit the Tokenizer on some data '
-                             'before using tfidf mode.')
+        if mode == "tfidf" and not self.document_count:
+            raise ValueError(
+                "Fit the Tokenizer on some data " "before using tfidf mode."
+            )
 
         x = np.zeros((len(sequences), num_words))
         for i, seq in enumerate(sequences):
@@ -439,32 +444,33 @@ class Tokenizer(object):
                     continue
                 counts[j] += 1
             for j, c in list(counts.items()):
-                if mode == 'count':
+                if mode == "count":
                     x[i][j] = c
-                elif mode == 'freq':
+                elif mode == "freq":
                     x[i][j] = c / len(seq)
-                elif mode == 'binary':
+                elif mode == "binary":
                     x[i][j] = 1
-                elif mode == 'tfidf':
+                elif mode == "tfidf":
                     # Use weighting scheme 2 in
                     # https://en.wikipedia.org/wiki/Tf%E2%80%93idf
                     tf = 1 + np.log(c)
-                    idf = np.log(1 + self.document_count /
-                                 (1 + self.index_docs.get(j, 0)))
+                    idf = np.log(
+                        1 + self.document_count / (1 + self.index_docs.get(j, 0))
+                    )
                     x[i][j] = tf * idf
                 else:
-                    raise ValueError('Unknown vectorization mode:', mode)
+                    raise ValueError("Unknown vectorization mode:", mode)
         return x
 
     def get_config(self):
-        '''Returns the tokenizer configuration as Python dictionary.
+        """Returns the tokenizer configuration as Python dictionary.
         The word count dictionaries used by the tokenizer get serialized
         into plain JSON, so that the configuration can be read by other
         projects.
 
         # Returns
             A Python dictionary with the tokenizer configuration.
-        '''
+        """
         json_word_counts = json.dumps(self.word_counts)
         json_word_docs = json.dumps(self.word_docs)
         json_index_docs = json.dumps(self.index_docs)
@@ -472,18 +478,18 @@ class Tokenizer(object):
         json_index_word = json.dumps(self.index_word)
 
         return {
-            'num_words': self.num_words,
-            'filters': self.filters,
-            'lower': self.lower,
-            'split': self.split,
-            'char_level': self.char_level,
-            'oov_token': self.oov_token,
-            'document_count': self.document_count,
-            'word_counts': json_word_counts,
-            'word_docs': json_word_docs,
-            'index_docs': json_index_docs,
-            'index_word': json_index_word,
-            'word_index': json_word_index
+            "num_words": self.num_words,
+            "filters": self.filters,
+            "lower": self.lower,
+            "split": self.split,
+            "char_level": self.char_level,
+            "oov_token": self.oov_token,
+            "document_count": self.document_count,
+            "word_counts": json_word_counts,
+            "word_docs": json_word_docs,
+            "index_docs": json_index_docs,
+            "index_word": json_index_word,
+            "word_index": json_word_index,
         }
 
     def to_json(self, **kwargs):
@@ -499,10 +505,7 @@ class Tokenizer(object):
             A JSON string containing the tokenizer configuration.
         """
         config = self.get_config()
-        tokenizer_config = {
-            'class_name': self.__class__.__name__,
-            'config': config
-        }
+        tokenizer_config = {"class_name": self.__class__.__name__, "config": config}
         return json.dumps(tokenizer_config, **kwargs)
 
 
